import { registerBlockType } from '@wordpress/blocks';
import { useBlockProps, RichText, InspectorControls } from '@wordpress/block-editor';
import { PanelBody, TextControl } from '@wordpress/components';
import { useSelect } from '@wordpress/data';

registerBlockType('sectional-comments/comment-block', {
    title: 'Section Comments',
    icon: 'admin-comments',
    category: 'common',
    attributes: {
        sectionId: {
            type: 'string',
            default: '',
        },
        title: {
            type: 'string',
            default: 'Comments',
        },
    },
    edit: function Edit({ attributes, setAttributes }) {
        const blockProps = useBlockProps();

        const postTitle = useSelect(select => {
            return select('core/editor').getEditedPostAttribute('title');
        }, []);

        const postId = useSelect(select => {
            return select('core/editor').getCurrentPostId();
        }, []);

        if (!attributes.sectionId) {
            const defaultSectionId = `${postTitle.toLowerCase().replace(/\s+/g, '-')}-${postId}`;
            setAttributes({ sectionId: defaultSectionId });
        }

        return (
            <>
                <InspectorControls>
                    <PanelBody title="Section Comments Settings">
                        <TextControl
                            label="Section ID"
                            value={attributes.sectionId}
                            onChange={(sectionId) => setAttributes({ sectionId })}
                        />
                        <TextControl
                            label="Title"
                            value={attributes.title}
                            onChange={(title) => setAttributes({ title })}
                        />
                    </PanelBody>
                </InspectorControls>
                <div {...blockProps}>
                    <h3>{attributes.title}</h3>
                    <p>Section ID: {attributes.sectionId}</p>
                    <div className="comment-form">
                        <textarea placeholder="Write your comment here" disabled></textarea>
                        <button className="submit-comment" disabled>Submit Comment</button>
                    </div>
                    <div className="comment-list">
                        <p>Comments will appear here</p>
                    </div>
                </div>
            </>
        );
    },
    save: function Save({ attributes }) {
        const blockProps = useBlockProps.save();
        return (
            <div {...blockProps} data-section-id={attributes.sectionId}>
                <h3>{attributes.title}</h3>
                <div className="comment-form">
                    <form>
                        <textarea name="comment" placeholder="Write your comment here" required></textarea>
                        <button type="submit" className="submit-comment">Submit Comment</button>
                        <button type="button" className="cancel-comment">Cancel</button>
                    </form>
                </div>
                <div className="comment-list"></div>
            </div>
        );
    },
});