jQuery(document).ready(function($) {
    $('.wp-block-sectional-comments-comment-block').each(function() {
        var $block = $(this);
        var sectionId = $block.data('section-id');
        var $form = $block.find('.comment-form form');
        var $commentList = $block.find('.comment-list');
        var $cancelButton = $block.find('.cancel-comment');
        var $showMoreBtn = $('<button class="show-more-comments">Show More</button>');
        var page = 1;

        function loadComments(append = false) {
            $.ajax({
                url: sectionalCommentsAjax.ajax_url,
                type: 'GET',
                data: {
                    action: 'get_section_comments',
                    section_id: sectionId,
                    page: page,
                    nonce: sectionalCommentsAjax.nonce
                },
                success: function(response) {
                    if (response.success) {
                        var commentsHtml = '';
                        response.data.comments.forEach(function(comment) {
                            commentsHtml += `
                                <div class="comment">
                                    <div class="comment-avatar">
                                        <img src="${comment.avatar_url}" alt="User Avatar">
                                    </div>
                                    <div class="comment-content">
                                        <p>${comment.content}</p>
                                        <small>${comment.date}</small>
                                    </div>
                                </div>`;
                        });
                        if (append) {
                            $commentList.append(commentsHtml);
                        } else {
                            $commentList.html(commentsHtml);
                        }
                        if (response.data.has_more) {
                            $showMoreBtn.show();
                        } else {
                            $showMoreBtn.hide();
                        }
                    } else {
                        console.error('Failed to load comments:', response.data.message);
                    }
                },
                error: function(jqXHR, textStatus, errorThrown) {
                    console.error('AJAX error:', textStatus, errorThrown);
                }
            });
        }

        $form.on('submit', function(e) {
            e.preventDefault();
            var commentText = $form.find('textarea[name="comment"]').val();

            $.ajax({
                url: sectionalCommentsAjax.ajax_url,
                type: 'POST',
                data: {
                    action: 'submit_sectional_comment',
                    section_id: sectionId,
                    comment: commentText,
                    nonce: sectionalCommentsAjax.nonce
                },
                success: function(response) {
                    if (response.success) {
                        $form.find('textarea[name="comment"]').val('');
                        page = 1;
                        loadComments();
                    } else {
                        console.error('Failed to submit comment:', response.data.message);
                        alert('Failed to submit comment: ' + response.data.message);
                    }
                },
                error: function(jqXHR, textStatus, errorThrown) {
                    console.error('AJAX error:', textStatus, errorThrown);
                    alert('An error occurred while submitting the comment. Please try again.');
                }
            });
        });

        $cancelButton.on('click', function() {
            $form.find('textarea[name="comment"]').val('');
        });

        $block.append($showMoreBtn);
        $showMoreBtn.on('click', function() {
            page++;
            loadComments(true);
        });

        loadComments();
    });
});