import { registerBlockType } from '@wordpress/blocks';
import { useBlockProps, RichText, InspectorControls } from '@wordpress/block-editor';
import { PanelBody, TextControl, ToggleControl } from '@wordpress/components';

registerBlockType('sectional-comments/comment-block', {
    apiVersion: 2,
    title: 'Section Comments',
    icon: 'admin-comments',
    category: 'common',
    attributes: {
        sectionId: {
            type: 'string',
            default: '',
        },
        sectionTitle: {
            type: 'string',
            default: 'Comments',
        },
        buttonText: {
            type: 'string',
            default: 'Submit',
        },
        hideCommentBox: {
            type: 'boolean',
            default: false,
        },
    },
    edit: function Edit({ attributes, setAttributes }) {
        const blockProps = useBlockProps();
        return (
            <>
                <InspectorControls>
                    <PanelBody title="Section Comments Settings">
                        <TextControl
                            label="Section Title"
                            value={attributes.sectionTitle}
                            onChange={(sectionTitle) => setAttributes({ sectionTitle })}
                        />
                        <TextControl
                            label="Submit Button Text"
                            value={attributes.buttonText}
                            onChange={(buttonText) => setAttributes({ buttonText })}
                        />
                        <ToggleControl
                            label="Hide Comment Box"
                            checked={attributes.hideCommentBox}
                            onChange={(hideCommentBox) => setAttributes({ hideCommentBox })}
                        />
                    </PanelBody>
                </InspectorControls>
                <div {...blockProps}>
                    <RichText
                        tagName="p"
                        placeholder="Enter a unique identifier for this section"
                        value={attributes.sectionId}
                        onChange={(sectionId) => setAttributes({ sectionId })}
                    />
                    <h3>{attributes.sectionTitle}</h3>
                    <p>Section Comments Block (Editor View)</p>
                    <p>Comment Box: {attributes.hideCommentBox ? 'Hidden' : 'Visible'}</p>
                </div>
            </>
        );
    },
    save: function Save({ attributes }) {
        const blockProps = useBlockProps.save();
        return (
            <div {...blockProps} data-section-id={attributes.sectionId} data-hide-comment-box={attributes.hideCommentBox.toString()}>
                <h3>{attributes.sectionTitle}</h3>
                <div class="comment-form" style={{display: attributes.hideCommentBox ? 'none' : 'block'}}>
                    <form>
                        <textarea name="comment" placeholder="Write your comment here"></textarea>
                        <div class="form-actions">
                            <button type="button" class="cancel-comment">Cancel</button>
                            <button type="submit" class="submit-comment">{attributes.buttonText}</button>
                        </div>
                    </form>
                </div>
                <button class="toggle-comment-form" style={{display: attributes.hideCommentBox ? 'block' : 'none'}}>Add Comment</button>
                <div class="comment-list"></div>
            </div>
        );
    },
});